@@ -23,7 +23,7 @@
  * to your nearest servers.  However if you use a seperate 'ircII.servers'
  * file and the ircII can find it, this setting is overridden.
  */
-#define DEFAULT_SERVER	    "irc"
+#define DEFAULT_SERVER	    "us.undernet.org"
 
 /*
  * Uncomment the following if the gecos field of your /etc/passwd has other
@@ -69,7 +69,7 @@
  * If you undefine this you will spare some code, though, so better only
  * set if you are sure you are going to keep your help-files compressed.
  */
-#define ZCAT "/usr/bin/gzcat"
+#define ZCAT "/bin/zcat"
 
 /* Define ZSUFFIX in case we are using ZCAT */
 #ifdef ZCAT
@@ -101,7 +101,7 @@
  *	"help_UK"
  */
 
-#define	DEFAULT_HELP_SERVICE     NULL
+#define	DEFAULT_HELP_SERVICE     "help_US"
 
 /*
  * Uncomment the following to make ircII read a list of irc servers from
@@ -130,7 +130,7 @@
  * address, such as a floating slip machine.
  */
 
-#undef DYNAMIC_SLIP
+#define DYNAMIC_SLIP
 
 /*
  * Below are the IRCII variable defaults.  For boolean variables, use 1 for
