@@ -24,7 +24,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: help.c,v 1.29 1995/01/04 10:32:49 mrg stable $";
+static	char	rcsid[] = "@(#)$Id: help.c,v 1.30 1995/03/19 03:33:03 mrg Exp $";
 #endif
 
 #include "irc.h"
@@ -242,8 +242,11 @@ help_prompt(name, line)
 	}
 
 	if (show_help(help_window, name))
-		add_wait_prompt("*** Hit any key for more, 'q' to quit ***",
-			help_prompt, name, WAIT_PROMPT_KEY);
+		if (dumb)
+			help_prompt(name,(char *) 0);
+		else
+			add_wait_prompt("*** Hit any key for more, 'q' to quit ***",
+				help_prompt, name, WAIT_PROMPT_KEY);
 	else
 	{
 		finished_help_paging = 1;
@@ -251,9 +254,12 @@ help_prompt(name, line)
 		if (help_show_directory)
 		{
 			if (get_int_var(HELP_PAGER_VAR))
-				add_wait_prompt("*** Hit any key to end ***", 
-					help_show_paused_topic, paused_topic,
-					WAIT_PROMPT_KEY);
+				if (dumb)
+					help_show_paused_topic(paused_topic);
+				else
+					add_wait_prompt("*** Hit any key to end ***", 
+						help_show_paused_topic, paused_topic,
+						WAIT_PROMPT_KEY);
 			else
 			{
 				help_show_paused_topic(paused_topic);
@@ -272,8 +278,9 @@ help_prompt(name, line)
 
 			sprintf(tmp, "%s%sHelp? ", help_topic_list,
 				*help_topic_list ? " " : "");
-			add_wait_prompt(tmp, help_me, help_topic_list,
-				WAIT_PROMPT_LINE);
+			if (!dumb)
+				add_wait_prompt(tmp, help_me, help_topic_list,
+					WAIT_PROMPT_LINE);
 		}
 		else
 		{
@@ -456,7 +463,8 @@ help_show_paused_topic(name)
 		char	buf[BIG_BUFFER_SIZE];
 
 		sprintf(buf, "%s%sHelp? ", name, (name && *name) ? " " : "");
-		add_wait_prompt(buf, help_me, name, WAIT_PROMPT_LINE);
+		if (!dumb)
+			add_wait_prompt(buf, help_me, name, WAIT_PROMPT_LINE);
 	}
 	else
 		set_help_screen((Screen *) 0);
@@ -536,8 +544,9 @@ help_me(topics, args)
 			*help_topic_list = '\0';
 		sprintf(tmp, "%s%sHelp? ", help_topic_list,
 			*help_topic_list ? " " : "");
-		add_wait_prompt(tmp, help_me, help_topic_list,
-			WAIT_PROMPT_LINE);
+		if (!dumb)
+			add_wait_prompt(tmp, help_me, help_topic_list,
+				WAIT_PROMPT_LINE);
 		return;
 	}
 
@@ -624,8 +633,9 @@ help_me(topics, args)
 			}
 			sprintf(tmp, "%s%sHelp? ", help_topic_list,
 				*help_topic_list ? " " : "");
-			add_wait_prompt(tmp, help_me, help_topic_list,
-					WAIT_PROMPT_LINE);
+			if (!dumb)
+				add_wait_prompt(tmp, help_me, help_topic_list,
+						WAIT_PROMPT_LINE);
 			if (help_paused_first_call)
 			{
 				help_topic(help_paused_path, help_paused_name);
