@@ -10,7 +10,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: screen.c,v 1.31 1994/12/19 09:04:11 mrg stable $";
+static	char	rcsid[] = "@(#)$Id: screen.c,v 1.32 1995/03/19 03:30:20 mrg Exp $";
 #endif
 
 #include "irc.h"
@@ -1803,7 +1803,11 @@ create_additional_screen()
 		close(s);
 		unlink(sockaddr->sun_path);
 		old_timeout = dgets_timeout(5);
-		if (dgets(buffer, BIG_BUFFER_SIZE, current_screen->fdin) > 0)
+		/*
+		 * dgets returns 0 on EOF and -1 on timeout.  both of these are
+		 * error conditions in this case, so we bail out here.
+		 */
+		if (dgets(buffer, BIG_BUFFER_SIZE, current_screen->fdin) < 1)
 		{
 			close(current_screen->fdin);
 			kill_screen(current_screen);
