@@ -9,7 +9,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: server.c,v 1.35 1995/01/16 09:12:44 mrg Exp $";
+static	char	rcsid[] = "@(#)$Id: server.c,v 1.38 1995/04/03 13:46:06 mrg Exp $";
 #endif
 
 #include "irc.h"
@@ -292,7 +292,8 @@ find_in_server_list(server, port)
 	len = strlen(server);
 	for (i = 0; i < number_of_servers; i++)
 	{
-		if (port && server_list[i].port && port != server_list[i].port)
+		if (port && server_list[i].port &&
+		    port != server_list[i].port && port != -1)
 			continue;
 		len2 = strlen(server_list[i].name);
 		if (len2 > len)
@@ -431,7 +432,7 @@ add_to_server_list(server, port, password, nick, overwrite)
 	}
 }
 
-static	void
+extern	void
 remove_from_server_list(i)
 	int	i;
 {
@@ -577,7 +578,11 @@ build_server_list(servers)
 		{
 			parse_server_info(host, &port, &password, &nick);
 			if (port && *port)
+			{
 				port_num = atoi(port);
+				if (!port_num)
+					port_num = irc_port;
+			}
 			else
 				port_num = irc_port;
 			add_to_server_list(host, port_num, password, nick, 0);
@@ -1067,7 +1072,11 @@ server(command, args, subargs)
 			}
 		}
 		if ((port = next_arg(args, &args)) != NULL)
+		{
 			port_num = atoi(port);
+			if (!port_num)
+				port_num = irc_port;
+		}
 		else
 			port_num = irc_port;
 		if (*server == '+')
@@ -1646,6 +1655,22 @@ disconnectcmd(command, args, subargs)
 	}
 	else
 		i = get_window_server(0);
+	/*
+	 * XXX - this is a major kludge.  i should never equal -1 at
+	 * this point.  we only do this because something has gotten
+	 * *really* confused at this point.  .mrg.
+	 */
+	if (i == -1)
+	{
+		for (i = 0; i < number_of_servers; i++)
+		{
+			clear_channel_list(i);
+			server_list[i].eof = -1;
+			close(server_list[i].read);
+			close(server_list[i].write);
+		}
+		goto done;
+	}
 	if (!args || !*args)
 		message = "Disconnecting";
 	else
@@ -1656,8 +1681,10 @@ disconnectcmd(command, args, subargs)
 		return;
 	}
 	say("Disconnecting from server %s", server_list[i].itsname);
+	clear_channel_list(i);
 	close_server(i, message);
 	server_list[i].eof = 1;
+done:
 	clean_whois_queue();
 	window_check_servers();
 }
